package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.activity.ZxActivity;
import com.ruoyi.system.domain.activity.ZxActivityUser;

import java.util.List;


/**
 * 政协活动Mapper接口
 * 
 * @author boman
 * @date 2024-03-14
 */
public interface ZxActivityMapper 
{
    /**
     * 查询政协活动
     * 
     * @param activityId 政协活动主键
     * @return 政协活动
     */
    public ZxActivity selectZxActivityByActivityId(Long activityId);
    /**
     * 查询政协活动人员详情
     *
     * @param activityId 政协活动主键
     * @return 政协活动
     */
    public List<ZxActivityUser> selectZxActivityUserByActivityId(Long activityId);
    /**
     * 获取政协活动人员详细信息
     */
    public List<ZxActivityUser> selectZxActivityUser(ZxActivityUser zxActivityUser);

    /**
     * 查询政协活动列表
     * 
     * @param zxActivity 政协活动
     * @return 政协活动集合
     */
    public List<ZxActivity> selectZxActivityList(ZxActivity zxActivity);

    /**
     * 新增政协活动
     * 
     * @param zxActivity 政协活动
     * @return 结果
     */
    public int insertZxActivity(ZxActivity zxActivity);
    /**
     * 修改活动答复信息
     */
    public int updateReply(ZxActivityUser zxActivityUser);

    /**
     * 修改政协活动
     * 
     * @param zxActivity 政协活动
     * @return 结果
     */
    public int updateZxActivity(ZxActivity zxActivity);

    /**
     * 删除政协活动
     * 
     * @param activityId 政协活动主键
     * @return 结果
     */
    public int deleteZxActivityByActivityId(Long activityId);

    /**
     * 批量删除政协活动
     * 
     * @param activityIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZxActivityByActivityIds(Long[] activityIds);

    /**
     * 批量删除政协活动-用户关联
     * 
     * @param activityIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZxActivityUserByActivityIds(Long[] activityIds);
    
    /**
     * 批量新增政协活动-用户关联
     * 
     * @param zxActivityUserList 政协活动-用户关联列表
     * @return 结果
     */
    public int batchZxActivityUser(List<ZxActivityUser> zxActivityUserList);
    

    /**
     * 通过政协活动主键删除政协活动-用户关联信息
     * 
     * @param activityId 政协活动ID
     * @return 结果
     */
    public int deleteZxActivityUserByActivityId(Long activityId);
}
